#
# spec file for package ghc-esqueleto
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name esqueleto
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.4.3
Release:        4.11
Summary:        Type-safe EDSL for SQL queries on persistent backends
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
# https://github.com/prowdsponsor/esqueleto/pull/149
Patch1:         0001-Port-to-Stackage-Nightly-and-persistent-2.6.patch
Patch2:         0002-Fix-warnings-for-persistent-2.6.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-persistent-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-persistent-sqlite-devel
BuildRequires:  ghc-persistent-template-devel
%endif

%description
'esqueleto' is a bare bones, type-safe EDSL for SQL queries that works with
unmodified 'persistent' SQL backends. Its language closely resembles SQL, so
you don't have to learn new concepts, just new syntax, and it's fairly easy to
predict the generated SQL and optimize it for your backend. Most kinds of
errors committed when writing SQL are caught as compile-time errors---although
it is possible to write type-checked 'esqueleto' queries that fail at runtime.

'persistent' is a library for type-safe data serialization. It has many kinds
of backends, such as SQL backends ('persistent-mysql', 'persistent-postgresql',
'persistent-sqlite') and NoSQL backends ('persistent-mongoDB'). While
'persistent' is a nice library for storing and retrieving records, including
with filters, it does not try to support some of the features that are specific
to SQL backends. In particular, 'esqueleto' is the recommended library for
type-safe 'JOIN's on 'persistent' SQL backends. (The alternative is using raw
SQL, but that's error prone and does not offer any composability.)

Currently, 'SELECT's, 'UPDATE's, 'INSERT's and 'DELETE's are supported.
Not all SQL features are available, but most of them can be easily added
(especially functions), so please open an issue or send a pull request if you
need anything that is not covered by 'esqueleto' on
<https://github.com/prowdsponsor/esqueleto/>.

The name of this library means "skeleton" in Portuguese and contains all three
SQL letters in the correct order =). It was inspired by Scala's Squeryl but
created from scratch.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal
%patch1 -p1
%patch2 -p1

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)

%changelog
* Wed Sep 21 2016 psimons@suse.com
- Add 0001-Port-to-Stackage-Nightly-and-persistent-2.6.patch and
  0002-Fix-warnings-for-persistent-2.6.patch to add support for
  persistent library versions 2.5 or newer. These patches come from
  https://github.com/prowdsponsor/esqueleto/pull/149 and not yet
  available officially. We decided to apply them because this
  package is essential for git-annex.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.4.3 revision 1 with cabal2obs.
* Mon Feb 22 2016 psimons@suse.com
- initial version esqueleto-2.4.3
